# Frequenz Migrogrid API Release Notes

## Summary

This is the first public open source release based on the internal version v0.10.0. There are no breaking changes in this release, only changes to the
project structure, metadata, and automation. Packages are also now uploaded to PyPI as [`frequenz-api-microgrid`](https://pypi.org/project/frequenz-api-microgrid/), so this project now can be installed normally via `pip`:

```sh
python -m pip install frequenz-api-microgrid
```

The GitHub issues were also improved, adding templates for [reporting issues](https://github.com/frequenz-floss/frequenz-api-microgrid/issues/new?assignees=&labels=priority%3A%E2%9D%93%2C+type%3Abug&template=bug.yml) and [requesting features](https://github.com/frequenz-floss/frequenz-api-microgrid/issues/new?assignees=&labels=part%3A%E2%9D%93%2C+priority%3A%E2%9D%93%2C+type%3Aenhancement&template=feature.yml). Users are also pointed to the [Discussion forums](https://github.com/frequenz-floss/frequenz-api-microgrid/issues/new/choose) when trying to open an issue if they have questions instead. Also many labels are assigned automatically on issue and pull request creation.
